==> LoadL-3.3.2.4-0.RH4-X86_64.3.3.X.tar.gz: opt/ibmll/LoadL/full/samples/lldata_access/qfs.c <==
/*======================================================================*/
/*                                                                      */
/* Module Name: qfs.c                                                   */
/*                                                                      */
/*----------------------------------------------------------------------*/
/*                                                                      */
/* Description: This sample program uses the Data Access API to         */
/* obtain information about Fair Share Scheduling.                      */
/*                                                                      */
/*======================================================================*/
static char qfs_sccsid[] = "@(#) src/ll/samples/lldata_access/qfs.c, ll.api, ll_rmer, rmer0610a 1.1 10/27/05";

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <time.h>
#include "llapi.h"

extern char *optarg;

int free_strings(char **ppc) {
	char **p = ppc;
	while (*p) {
		free(*p);
		p++;
	}
	free (ppc);
	return 0;
}

void usage(void) {
	printf("\nUsage: qfs [-u user] [-g group]\n\n");
}

int main(int argc, char *argv[]) {
	int opt, rc = 0, i;

	char *u_list[2] = {NULL, NULL};
	char *g_list[2] = {NULL, NULL};
	LL_element  *queryObject = NULL;
	int obj_count = 0, err_code = 0;
	LL_element  *fair_share_data = NULL;

	time_t current_time = 0;
	int total_shares = 0;
	int interval = 0;
	int number_of_entries = 0;
	char **entry_names = NULL;
	int *entry_types = NULL;
	int *allocated_shares = NULL;
	int *used_shares = NULL;

	/* Parsing command line arguments */
	while ( (opt = getopt(argc, argv, "u:g:")) != EOF) {
		switch (opt) {
		case 'u':
			u_list[0] = optarg;
			break;
		case 'g':
			g_list[0] = optarg;
			break;
		default:
			usage();
			return(-1);
		}
	}

	/* Initialize the FAIRSHARE query */
	queryObject = ll_query(FAIRSHARE);
	if (!queryObject) {
		printf("ll_query(FAIRSHARE) returned NULL\n");
		return(-1);
	}

	if (u_list[0] == NULL && g_list[0] == NULL) {
		rc = ll_set_request(queryObject, QUERY_ALL, NULL, ALL_DATA);
	}
	if (u_list[0] != NULL) {
		rc = ll_set_request(queryObject, QUERY_USER, u_list, ALL_DATA);
	}
	if (g_list[0] != NULL) {
		rc = ll_set_request(queryObject, QUERY_GROUP, g_list, ALL_DATA);
	}
	if (rc) {
		printf("ll_set_request returned %d\n", rc);
		return(-1);
	}

	/* get data */
	fair_share_data = ll_get_objs(queryObject, LL_CM, NULL, &obj_count, &err_code);
	if (err_code) { // error getting data due to communication problem
		if (err_code == API_NOT_ENABLED) {
			printf("Fair Share Scheduling is not turned on.\n");
		} else if (err_code == API_NOT_SUPPORTED) {
			printf("Fair Share Scheduling is not supported.\n");
		} else if (err_code == API_NO_PERMISSION) {
			printf("You are not permitted to issue this command.\n");
		} else {
			printf("Failed to connect to LoadLeveler.\n");
		}
		return (-1);
	}

	if (obj_count != 1) { // if no Fair Share Data found
		printf("No entry is found for Fair Share Scheduling.\n");
		return(0);
	}

	rc = ll_get_data(fair_share_data, LL_FairShareCurrentTime, &current_time);
	rc = ll_get_data(fair_share_data, LL_FairShareTotalShares, &total_shares);
	rc = ll_get_data(fair_share_data, LL_FairShareInterval, &interval);
	rc = ll_get_data(fair_share_data, LL_FairShareNumberOfEntries, &number_of_entries);
	rc = ll_get_data(fair_share_data, LL_FairShareEntryNames, &entry_names);
	rc = ll_get_data(fair_share_data, LL_FairShareEntryTypes, &entry_types);
	rc = ll_get_data(fair_share_data, LL_FairShareAllocatedShares, &allocated_shares);
	rc = ll_get_data(fair_share_data, LL_FairShareUsedShares, &used_shares);

	/* print data */
	printf("Current Time: %d\n", current_time);
	printf("FAIR_SHARE_TOTAL_SHARES = %d\n", total_shares);
	printf("FAIR_SHARE_INTERVAL = %d hours\n", interval);
	printf("\nName                 Type  Allocated Shares Used Shares\n");
	printf("-------------------- ----- ---------------- -----------\n");

	for (i=0; i<number_of_entries; i++) {
		printf("%-20s %-5s %-16d %d\n", entry_names[i], entry_types[i] ? "group" : "user", allocated_shares[i], used_shares[i]);
	}

	/* clean up */
	ll_free_objs(queryObject);
	ll_deallocate(queryObject);
	free_strings(entry_names);
	entry_names = NULL;
	free(entry_types);
	entry_types = NULL;
	free(allocated_shares);
	allocated_shares = NULL;
	free(used_shares);
	used_shares = NULL;

	return 0;
}

==> LoadL-3.3.2.20-0.RH4-X86.3.3.X.tar.gz: opt/ibmll/LoadL/full/samples/lldata_access/qfs.c <==
/*======================================================================*/
/*                                                                      */
/* Module Name: qfs.c                                                   */
/*                                                                      */
/*----------------------------------------------------------------------*/
/*                                                                      */
/* Description: This sample program uses the Data Access API to         */
/* obtain information about Fair Share Scheduling.                      */
/*                                                                      */
/*======================================================================*/
static char qfs_sccsid[] = "@(#) src/ll/samples/lldata_access/qfs.c, ll.api, ll_rmer, rmers008a 1.1.1.1 11/2/06";

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <time.h>
#include "llapi.h"

extern char *optarg;

int free_strings(char **ppc) {
	char **p = ppc;
	while (*p) {
		free(*p);
		p++;
	}
	free (ppc);
	return 0;
}

void usage(void) {
	printf("\nUsage: qfs [-u user] [-g group]\n\n");
}

int main(int argc, char *argv[]) {
	int opt, rc = 0, i;

	char *u_list[2] = {NULL, NULL};
	char *g_list[2] = {NULL, NULL};
	LL_element  *queryObject = NULL;
	int obj_count = 0, err_code = 0;
	LL_element  *fair_share_data = NULL;

	time_t current_time = 0;
	int total_shares = 0;
	int interval = 0;
	int number_of_entries = 0;
	char **entry_names = NULL;
	int *entry_types = NULL;
	int *allocated_shares = NULL;
	int *used_shares = NULL;

	/* Parsing command line arguments */
	while ( (opt = getopt(argc, argv, "u:g:")) != EOF) {
		switch (opt) {
		case 'u':
			u_list[0] = optarg;
			break;
		case 'g':
			g_list[0] = optarg;
			break;
		default:
			usage();
			return(-1);
		}
	}

	/* Initialize the FAIRSHARE query */
	queryObject = ll_query(FAIRSHARE);
	if (!queryObject) {
		printf("ll_query(FAIRSHARE) returned NULL\n");
		return(-1);
	}

	if (u_list[0] == NULL && g_list[0] == NULL) {
		rc = ll_set_request(queryObject, QUERY_ALL, NULL, ALL_DATA);
	}
	if (u_list[0] != NULL) {
		rc = ll_set_request(queryObject, QUERY_USER, u_list, ALL_DATA);
	}
	if (g_list[0] != NULL) {
		rc = ll_set_request(queryObject, QUERY_GROUP, g_list, ALL_DATA);
	}
	if (rc) {
		printf("ll_set_request returned %d\n", rc);
		return(-1);
	}

	/* get data */
	fair_share_data = ll_get_objs(queryObject, LL_CM, NULL, &obj_count, &err_code);
	if (err_code) { /* error getting data due to communication problem */
		if (err_code == API_NOT_ENABLED) {
			printf("Fair Share Scheduling is not turned on.\n");
		} else if (err_code == API_NOT_SUPPORTED) {
			printf("Fair Share Scheduling is not supported.\n");
		} else if (err_code == API_NO_PERMISSION) {
			printf("You are not permitted to issue this command.\n");
		} else {
			printf("Failed to connect to LoadLeveler.\n");
		}
		return (-1);
	}

	if (obj_count != 1) { /* if no Fair Share Data found */
		printf("No entry is found for Fair Share Scheduling.\n");
		return(0);
	}

	rc = ll_get_data(fair_share_data, LL_FairShareCurrentTime, &current_time);
	rc = ll_get_data(fair_share_data, LL_FairShareTotalShares, &total_shares);
	rc = ll_get_data(fair_share_data, LL_FairShareInterval, &interval);
	rc = ll_get_data(fair_share_data, LL_FairShareNumberOfEntries, &number_of_entries);
	rc = ll_get_data(fair_share_data, LL_FairShareEntryNames, &entry_names);
	rc = ll_get_data(fair_share_data, LL_FairShareEntryTypes, &entry_types);
	rc = ll_get_data(fair_share_data, LL_FairShareAllocatedShares, &allocated_shares);
	rc = ll_get_data(fair_share_data, LL_FairShareUsedShares, &used_shares);

	/* print data */
	printf("Current Time: %d\n", current_time);
	printf("FAIR_SHARE_TOTAL_SHARES = %d\n", total_shares);
	printf("FAIR_SHARE_INTERVAL = %d hours\n", interval);
	printf("\nName                 Type  Allocated Shares Used Shares\n");
	printf("-------------------- ----- ---------------- -----------\n");

	for (i=0; i<number_of_entries; i++) {
		printf("%-20s %-5s %-16d %d\n", entry_names[i], entry_types[i] ? "group" : "user", allocated_shares[i], used_shares[i]);
	}

	/* clean up */
	ll_free_objs(queryObject);
	ll_deallocate(queryObject);
	free_strings(entry_names);
	entry_names = NULL;
	free(entry_types);
	entry_types = NULL;
	free(allocated_shares);
	allocated_shares = NULL;
	free(used_shares);
	used_shares = NULL;

	return 0;
}
